@@ -1,7 +1,12 @@
+from __future__ import annotations
+
+import argparse
+from pathlib import Path
+
 from sr.comp.cli import add_delay, deploy
 
 
-def command(args):
+def command(args: argparse.Namespace) -> None:
     from sr.comp.raw_compstate import RawCompstate
 
     compstate = RawCompstate(args.compstate, local_only=False)
@@ -31,7 +36,7 @@ def command(args):
     deploy.run_deployments(args, compstate, hosts)
 
 
-def add_subparser(subparsers):
+def add_subparser(subparsers: argparse._SubParsersAction[argparse.ArgumentParser]) -> None:
     help_msg = "Add and deploy a delay to the competition"
     parser = subparsers.add_parser('delay', help=help_msg, description=help_msg)
     parser.add_argument(
@@ -40,6 +45,10 @@ def add_subparser(subparsers):
         help="skips updating to the latest revision",
     )
     deploy.add_options(parser)
-    parser.add_argument('compstate', help="competition state repository")
+    parser.add_argument(
+        'compstate',
+        type=Path,
+        help="competition state repository",
+    )
     add_delay.add_arguments(parser)
     parser.set_defaults(func=command)
